Dtattributeimage

#
Image Attributes

Attribute Name | Tag | Type | VR | VM | Descriptiom | Creator | Unit
General Image Attributes |  |  |  |
AcquisitionDate | 0008,0022 | 3 | DA | 1 | A number identifying the single continuous gathering of data over a period of time which resulted in this image | acquisition |
ContentDate | 0008,0023 | 2C | DA | 1 | The date the image data creation started. Required if image is part of a series in which the images are temporally related | acquisition |
AcquisitionTime | 0008,0032 | 3 | TM | 1 | The time the acquisition of data that resulted in this image started | acquisition |
ContentTime | 0008,0033 | 2C | TM | 1 | The time the image pixrl data creation started. Required if image is part of a series in which the images are temporally related | acquisition |
Acquisition Datetime | 0008,002A | 3 | DT | 1 | The date and time that the acquisition of dada that result in this image started |  |
DerivationDescription | 0008,2111 | 3 | ST | 1 | A text description of how this image was derived | image creator |
AcquisitionNumber | 0020,0012 | 2 | IS | 1 | Image identification characteristics | acquisition |
InstanceNumber | 0020,0013 | 2 | IS | 1 | A number that identifies this image | acquisition |
ImageComments | 0020,4000 | 3 | LT | 1 | User-defined comments about the image | acquisition user interface |
ImageInAcquisition | 0020,1002 | 3 | IS | 1 | Number of images that resulted from this acquisition of data |  |
ReferencedImageSequence | 0008,1140 | 3 | link | 1 | A sequence which provides reference to a set of Image SOP Class/Instance identifying other images significantly related to this image (localizer images) | acquisition |
>Referenced SOP Class UID | 0008,1150 | 1C | UI | 1 | Uniquely identifies the referenced SOP Class | acquisition |
>Referenced SOP Instance UID | 0008,1155 | 1C | UI | 1 | Uniquely identifies the referenced SOP Instance | acquisition |
> Referenced Frame Number | 0008,1160 | 3 | IS | 1-n | References one or more image frames of a Multi-frame Image SOP Instance, identifying which frames are siginificantly related to this image | acquisition |
SourceImageSequence | 0008,2112 | 3 | link | 1 | A sequence which identifies the set of Image SOP Class/Instance pairs of the images which were use to derive this image | acquisition |
>Referenced SOP Class UID | 0008,1150 | 1C | UI | 1 | Uniquely identifies the referenced SOP Class | acquisition |
>Referenced SOP Instance UID | 0008,1155 | 1C | UI | 1 | Uniquely identifies the referenced SOP Instance | acquisition |
> Referenced Frame Number | 0008,1160 | 3 | IS | 1-n | References one or more image frames of a Multi-frame Image SOP Instance, identifying which frames are siginificantly related to this image | acquisition |
ImageType | 0008,0008 | 3 | CS | 1-n | Image identification characteristics | acquisition |
Lossy Image Compression | 0028,0300 | 3 | CS | 1 | Specifies whether an image has undergone lossy compression. Enumerated values: 00 = image has not been subjected to lossy compression. 01 = image has been subjected to lossy compression | image creator |
Quality Control Image | 0008,0005 | 1C | CS | 1 | Indicates whether or not this image is a quality control or phantom image. Enumerated values: YES, NO | image creator |
PatientOrientation | 0020,0020 | 2 | CS | k | Patient direction of the rows and columns of the image. Not required for MR images |  |
MR Image Attributes |  |  |  |
ImageType | 0008,0008 | 1 | CS | 1-n | Image identification characteristics | acquisition |
Samples per Pixel | 0028,0002 | 1 | US | 1 | Number of samples (planes) in this image | acquisition |
PhotometricInterpretation | 0028,0004 | 1 | CS | 1 | Specifies the intended interpretation of the pixel data | acquisition |
BitsAllocated | 0028,0100 | 1 | US | 1 | Number of bits allocated for each pixel sample. Each sample shall have the same number of bits allocated | acquisition |
Scanning Sequence | 0018,0020 | 1 | CS | 1-n | Description of the type of data taken. Enumerated values: SE = Spin Echo; IR = Inversion Recovery; GR = Gradient Recalled; EP = Echo Planar; RM = Research Mode | acquisition |
SequenceVariant | 0018,0021 | 1 | CS | 1-n | Variant of the Scanning Sequence | acquisition |
ScanOptions | 0018,0022 | 2 | CS | 1-n | Parameters of scanning sequence | acquisition |
MRAcquisitionType | 0018,0023 | 2 | CS | 1 | Identification of date encoding scheme. Enumerated Values: 2D = frequency x phase 3D = frequency x phase x phase | acquisition |
SequenceName | 0018,0024 | 3 | SH | 1 | User defined name for the Scanning Sequence and Sequence Varaint combination | acquisition |
AngioFlag | 0018,0025 | 3 | CS | 1 | Angio image indicator. Primary image for angio processing. Enumerated values: Y = image is Angio N = image is not Angio | acquisition |
RepetitionTime | 0018,0080 | 2C | DS | 1 | The period of time in msec between the beginning of a pulse sequence and the beginning of a succeeding (essentially identical) pulse sequence. Required except when Scanning Sequence is EP and Sequnece Variant is not segmented k-space | acquisition | msec
EchoTime | 0018,0081 | 2 | DS | 1 | Time in msec between the middle of the excitation pulse and the peak of the echo produced. In the case of segmented k-space, the TE(eff) is the time between the middle of the excitation pulse to the peak of the echo that is used to cover the center of k-space) | acquisition | msec
InversionTime | 0018,0082 | 2C | DS | 1 | Time in msec after the middle of inverting RF pulse to middle of excitation pulse to detect the amount of longitudinal magnetization. Required if Scanning Sequence has value of IR | acquisition | msec
NumberOfAverages | 0018,0083 | 3 | DS | 1 | Number of times a given pulse sequence is repeated before any parameter has changed | acquisition |
ImagingFrequency | 0018,0084 | 3 | DS | 1 | Precession frquency in MHz of the nucleus being addressed | acquisition | MHz
ImagedNucleus | 0018,0085 | 3 | SH | 1 | Nucleus that is resonant at the imaging frequency | acquisition |
EchoNumbers | 0018,0086 | 3 | IS | 1-n | The echo number used in generating this image. In the case of segmented k-space, it is the effective Echo Number | acquisition |
MagneticFieldStrength | 0018,0087 | 3 | DS | 1 | Nominal Field strength of MR magnet, in Tesla | acquisition | Tesla
SpacingBetweenSlices | 0018,0088 | 3 | DS | 1 | Spacing between slices, in mm. The spacing is measured from the center-to-center of each slice | acquisition | mm
NumberOfPhaseEncodingSteps | 0018,0089 | 3 | IS | 1 | Total number of lines in k-space in the y-direction collecting during acquisition | acquisition |
EchoTrainLength | 0018,0091 | 2 | IS | 1 | Number of lines in k-space acquired per excitation per image | acquisition |
PercentSampling | 0018,0093 | 3 | DS | 1 | Fraction of acquisition matrix lines acquired, expressed as a percent | acquisition |
PercentPhaseFieldOfView | 0018,0094 | 3 | DS | 1 | Ration of field of view dimension in phase direction to field of view dimension in frequency direction, expressed as a percent | acquisition |
PixelBandwidth | 0018,0095 | 3 | DS | 1 | Reciprocal of the total sampling period, in hertz per pixel | acquisition | hertz/pixel
BeatRejectionFlag | 0018,1080 | 3 | CS | 1 | Beat length sorting has been applied. Enumerated values: Y = yes N = no | acquisition |
Low R-R Value | 0018,1081 | 3 | IS | 1 | R-R interval low limit for beat rejection, in msec | acquisition | msec
High R-R Value | 0018,1082 | 3 | IS | 1 | R-R interval high limit for beat rejection, in msec | acquisition | msec
TriggerTime | 0018,1060 | 2C | DS | 1 | Time, in msec, between peak of the R wave and the peak of the echo produced. In the case of segmented k-space, the TE(eff) is the time between the peak of the echo that is used to cover the center of k-space. Required for Scan Options which include heart gating | acquisition | msec
NominalInterval | 0018,1062 | 3 | IS | 1 | Average R-R interval used for the scans, in msec | acquisition | msec
IntervalsAcquired | 0018,1083 | 3 | IS | 1 | Number of R-R intervals acquired | acquisition |
IntervalsRejected | 0018,1083 | 3 | IS | 1 | Number of R-R intervals rejected | acquisition |
PVC Rejection | 0018,1085 | 3 | LO | 1 | Description of type of PVC rejection criteria used | acquisition |
Skip Beats | 0018,1086 | 3 | IS | 1 | Number of beats skipped after a detected arrhythmia | acquisition |
HeartRate | 0018,1088 | 3 | IS | 1 | Beats per minute | acquisition | 1/min
CardiacNumberOfImages | 0018,1090 | 3 | IS | 1 | Number of imagesb per cardiac cycle | acquisition |
TriggerWindow | 0018,1094 | 3 | IS | 1 | Percent of R-R interval, based on Heart Rate (0018,1088), prescriped as a window for a valid/usable trigger |  |
ReconstructionDiameter | 0018,1100 | 3 | DS | 1 | Diameter in mm of the region from within which data were used in creating the reconstruction of the image. Data may exist outside this region and portions of the patient may exist outside the region | acquisition |
Receive Coil | 0018,1250 | 3 | SH | 1 | Received coil used | acquisition |
TransmittingCoil | 0018,1251 | 3 | SH | 1 | Transmitted coil used | acquisition |
AcquisitionMatrix | 0018,1310 | 3 | US | 4 | Dimension of acquired frequency/phase data before reconstruction. Multi-valued: frequency rows\frequency columns\phase rows\phase columns | acquisition |
PhaseEncodingDirection | 0018,1312 | 3 | CS | 1 | The axis of phase encoding with respect to the image. Enumerated Values: ROW = phase encoded in rows COL = phase encoded in columns | acquisition |
FlipAngle | 0018,1314 | 3 | DS | 1 | Steady state angle in degrees to which the magnetic vector is flipped from the magnetic vector to the primary field | acquisition | degree
VariableFlipAngleFlag | 0018,1315 | 3 | CS | 1 | Flip angle variation applied during image acquisition. Enumerated Values: Y = yes N = no | acquisition |
SAR | 0018,1316 | 3 | DS | 1 | Calculated whole body specific absortion rate in watts/kilogram | acquisition | Watt/kilogram
dbdt | 0018,1318 | 3 | DS | 1 | The rate of change of the gradient coil magnetic flux density with time (T/s) | acquisition | Tesla/sec
Contrast Bolus Attributes |  |  |  |
ContrastBolusAgent | 0018,0010 | 2 | LO | 1 | Contrast or bolus agent | acquisition user interface |
ContrastBolusStartTime | 0018,1042 | 3 | TM | 1 | Time of start of injection | acquisition user interface |
ContrastBolusStopTime | 0018,1043 | 3 | TM | 1 | Time of end of contrast injection | acquisition user interface |
ContrastBolusTotalDose | 0018,1044 | 3 | DS | 1 | Total amount in milliliters of the indiluted contrast agent | acquisition user interface | ml
Contrast Flow Rate(s) | 0018,1046 | 3 | DS | 1-n | Rate(s) of injection(s) in millilitres/sec | acquisition user interface | ml/sec
ContrastBolusVolume | 0018,1041 | 3 | DS | 1 | Volume injected in milliliters of diluted contrast agent | acquisition user interface |
ContrastFlowDurations | 0018,1047 | 3 | DS | 1-n | Duration(s) of injection(s) in seconds. Each Contrast Flow Duration value shall correspond to a value of Contrast Flow Rate (0018,1046) | acquisition user interface | sec
Contrast/Bolus Ingredient | 0018,1048 | 3 | CS | 1 | Active ingredient of agent, Defined Terms: IODINE, GADOLIMIUM, CARBON DIOXIDE, BARIUM | acquisition user interface |
Contrast/Bolus Ingredient Concentration | 0018,1049 | 3 | DS | 1 | Milligrams of active ingredient per milliliter of (diluted) agent | acquisition user interface | mg/ml
Image Pixel Attributes |  |  |  |
SamplesPerPixel | 0028,0002 | 1 | US | 1 | Number of samples (planes) in this image | acquisition |
PhotometricInterpretation | 0028,0004 | 1 | CS | 1 | Specifies the intended interpretation of the pixel data | acquisition |
Rows | 0028,0010 | 1 | US | 1 | Number of rows in the image | acquisition |
Columns | 0028,0010 | 1 | US | 1 | Number of columns in the image | acquisition |
PixelAspectRatio | 0028,0034 | 1C | IS | 2 | Ratio of the vertical size and horizontal size of the pixels in the image specified by a pair of integer values where the first value is the vertical pixel size, and the second value is the horizontal pixel size. Required if the aspect ratio is not 1/1 and the Image Plane Module is not applicable to this Image | acquisition |
BitsAllocated | 0028,0100 | 1 | US | 1 | Number of bits allocated for each pixel sample. Each sample shall have the same number of bits allocated | acquisition |
BitsStored | 0028,0101 | 1 | US | 1 | Number of bits stored for each pixel sample. Each sample shall have the same number of bits stored | acquisition |
HighBit | 0028,0102 | 1 | US | 1 | Most significant bit for pixel sample data. Each sample shall have the same high bit | acquisition |
PixelRepresentation | 0028,0103 | 1 | US | 1 | Data representation of the pixel samples. Each sample shall have the same pixel representation. Enumerated values: 0000H = unsigned integer. 0001H = 2's complement. | acquisition |
PixelData | 7FE0,0010 | 1 | OW/OB | 1 | A data stream of the pixel samples which comprises the image | acquisition |
Smallest Image Pixel Value | 0028,0106 | 3 | US/SS | 1 | The minimum actual pixel value encountered in this image | acquisition |
Largest Image Pixel Value | 0028.0107 | 3 | US/SS | 1 | The maximum actual pixel value encountered in this image | acquisition |
Image Plane Attributes |  |  |  |
SliceThickness | 0018,0050 | 2 | DS | 1 | Nominal slice thickness, in mm | acquisition | mm
ImageOrientationPatient | 0020,0037 | 1 | DS | 6 | The direction cosines of the first row and the first column with respect to the patient | acquisition |
ImagePositionPatient | 0020,0032 | 1 | DS | 3 | The x,y and z coordinates of the upper left and hand corner (first pixel transmitted) of the image, in mm | acquisition | mm
SliceLocation | 0020,1041 | 3 | DS | 1 | Relative position of exposure expressed in mm | acquisition | mm
PixelSpacing | 0028,0030 | 1 | DS | 2 | Physical distance in the patient between the center of each pixel, specified by a numeric pair-adjacent row spacing (delimiter) adjacent column spacing in mm | acquisition | mm
VOI Lookup Table |  |  |  |
WindowCenter | 0028,1050 | 3 | DS | 1-n | Window center | acquisition/application |
WindowWidth | 0028,1050 | 1C | DS | 1-n | Window width | acquisition/application |
WindowCenterWidthExplanation | 0028,1055 | 3 | LO | 1-n | Free form explanation of the meaning of the Window Center and Width. Multiple values correspond to multiple Window Center and Width values | acquisition/application |
Equipment Attributes |  |  |  |  |  |  |
Manufacturer | 0008,0070 | 2 | LO | 1 | Manufacturer of the equipment that produced the digital images | acquisition/application |
InstitutionName | 0008,0080 | 3 | LO | 1 | Institution where the equipment is located that produced the digital images | acquisition/application |
InstitutionAddress | 0008,0081 | 3 | ST | 1 | Mailing address of the institution where the equipment is located that produced the digital images | acquisition/application |
ManufacturersModelName | 0008,1090 | 3 | LO | 1 | Manufacturer's model number of the equipment that produced the digital images | acquisition/application |
DeviceSerialNumber | 0018,1000 | 3 | LO | 1 | Manufacturer's seriel number of the equipment that produced the digital images | acquisition/application |
SoftwareVersions | 0018,1020 | 3 | LO | 1-n | Manufacturer's designation of software of the equipment that produced the digital images | acquisition/application |
Overlay Idendification Attributes |  |  |  |  |  |  |
OverlayRows | 60xx,0010 | 1 | US | 1 | Number of Rows in Overlay | post-processing applications |
OverlayColumns | 60xx,0011 | 1 | US | 1 | Number of Columns in Overlay | post-processing applications |
OverlayType | 60xx,0040 | 1 | CS | 1 | Indicates whether this overlay represents a region of interest or other graphics | post-processing applications |
Overlay Origin | 60xx,0050 | 1 | US | 1 | Location of first overlay point with respect to pixel in the image, given as row\column | post-processing applications |
OverlayBitsAllocated | 60xx,0100 | 1 | US | 1 | Number of bits allocated in the overlay | post-processing applications |
OverlayBitPosition | 60xx,0102 | 1 | US | 1 | Bit in which overlay is stored | post-processing applications |
Overlay Data | 60xx,3000 | 1C | OB/OW | 1 | Overlay pixel data | post-processing applications |
MEDCOM Header |  |  |  |  |  |  |
HeaderType | 0029,xx08 | 1C | CS | 1 | Medcom header characteristics. Defined Terms: MEDCOM 1 | acquisition |
HeaderVersion | 0029,xx09 | 2C | LO | 1 | Version of Medcom header | acquisition |
HeaderInfo | 0029,xx10 | 3 | OB | 1 | Manufacturer header info | acquisition |
HistoryInfo | 0029,xx20 | 3 |  | 1 | Patient registration history | patient registration |
MR and SC Private Attributes |  |  |  |  |  |  |
EchoLinePosition | stream | 1 | IS | 1 | Fourier line position with the maximal echo for the performed acquisition | acquisition |
EchoColumnPosition | stream | 1 | IS | 1 | Echo column position for the performed acquisition | acquisition |
EchoPartitionPosition | stream | 1 | IS | 1 | Echo partition position for the performed acquisition | acquisition |
UsedChannelMask | stream | 1 | UL | 1 | 8 bit mask of the used receiver channels for the performed acquisition. Example: channel 0: 00000001 channel 3: 00000111 · | acquisition |
Actual3DImaPartNumber | stream | 1 | IS | 1 | Number of a 3D partitions beginning with 0 | acquisition |
ICE_Dims | stream | 1 | LO | 1 | The 9 used ICE object dimensions of the performed acquisition. Combined/unset dimensions will be marked with "X". E.g.: X_2_1_1_1_1_2_1_1 | acquisition |
B_value | stream |  | IS | 1 | Diffusion effect in s/mm*mm of the ICE program for the performed acquisition | acquisition | sec/(mm*mm)
Filter1 | stream | 1 | IS |  | Context vision filter | acquisition |
Filter2 | stream | 1 | IS |  | not used | acquisition |
ProtocolSliceNumber | stream | 1 | IS | 1 | Number of the slice beginning with 0 | acquisition |
RealDwellTime | stream | 1 | IS | 1 | The time in ns between the beginning of sampling one data point and the beginning of sampling of next data point in the acquired signal. This means the dwell time is the sampling rate during digital conversion of an acquired signal | acquisition | nanosec
PixelFile | stream | 1 | UN | 1 | Used raw data file for the performed acquisition | acquisition |
PixelFileName | stream | 1 | UN | 1 | Used raw data file name for the performed acquisition |  |
SliceMeasurementDuration | stream | 1 | DS | 1 | Time duration between two slices of the performed acquisition | acquisition | msec
AcquisitionMatrixText | stream | 1 | SH | 1 | Used acquisition matrix description | acquisition |
SequenceMask | stream | 1 | UL | 1 | Parameters used for acquisition, e.g. door open, interpolation, raw filter, Siemens seqence .... | acquisition |
MeasuredFourierLines | stream | 1 | IS | 1 | Number of performed fourier lines | acquisition |
FlowEncodingDirection | stream |  | IS | 1 | Flow encoding direction | acquisition |
FlowVenc | stream |  | FD | 1 | Flow Quant attribute | acquisition |
PhaseEncodingDirectionPositive | stream |  | IS | 1 | Phase encoding direction: 0 = negative; 1 = positive | acquisition |
NumberOfImagesInMosaic | stream |  | US | 1 | Number of slices in a mosaic image | acquisition |
DiffusionGradientDirection | stream |  | FD | 3 | Diffusion in gradient direction | acquisition |
ImageGroup | stream |  | US | 1 | Group of images | acquisition |
SliceNormalVector | stream |  | FD | 3 | X,y and z normal vector of the slices | acquisition |
DiffusionDirection | stream |  | CS | 1 | Diffusion direction | acquisition |
TimeAfterStart | stream |  | DS | 1 | Time delay after start of measurment | acquisition |
FlipAngle | stream |  | DS | 1 | Flip angle for SC images | acquisition | degree
SequenceName | stream |  | SH | 1 | Sequence name for SC images | acquisition |
RepetitionTime | stream |  | DS | 1 | Repetition time for SC images | acquisition | msec
EchoTime | stream |  | DS | 1 | Echo time for SC images | acquisition | msec
NumberOfAverages | stream |  | DS | n | Number of averages for SC images | acquisition |
MR NonImage (Raw Data, Spectra) Attributes |  |  |  |  |  |  |
NonimageType | 0029,xx08 | 1 | CS | 1 | Data identification characteristics. Defined terms: RAW DATA NUM 4; SPEC NUM4 | acquisition |
NonimageVersion | 0029,xx09 | 3 | LO | 1 | Version of Non-image data | acquisition |
NonimageInfo | 0029,xx10 | 3 | OB | 1 | Description of Non-image data | acquisition |
NonimageData | 7FE1,xx10 | 2 | OB | 1 | Binary data stream | acquisition |
ImageType | 0008,0008 | 3 | CS | 1-n | Image identification characteristics | acquisition |
AcquisitionDate | 0008,0022 | 3 | DA | 1 | The date the acquisition of data started | acquisition |
AcquisitionTime | 0008,0032 | 3 | TM | 1 | The time the acquisition of data started | acquisition |
DerivationDescription | 0008,2111 | 3 | ST | 1 | A text description of how this data set was derived | acquisition |
AcquisitionNumber | 0020,0012 | 2 | IS | 1 | A number identifying the gathering of data over a period of time which resulted in this data set | acquisition |
ImageNumber | stream |  | IS | 1 | A number that identifies this image | acquisition |
ImageComments | stream |  | LT | 1 | User-defined comments about the image | acquisition |
ReferencedImageSequence | stream |  | UI | n | A sequence which provides reference to a set of Image SOP Class/Instance identifying other images significantly related to this image (localizer images) | acquisition |
PatientOrientation | stream |  | CS | 1 | Patient direction of the rows and columns of the image. Not required for MR images | acquisition |
ScanningSequence | stream |  | CS | n | Description of the type of data taken. Enumerated values: SE = Spin Echo; IR = Inversion Recovery; GR = Gradient Recalled; EP = Echo Planar; RM = Research Mode | acquisition |
SequenceName | stream |  | SH | 1 | User defined name for the Scanning Sequence and Sequence Varaint combination | acquisition |
RepetitionTime | stream |  | DS | 1 | The period of time in msec between the beginning of a pulse sequence and the beginning of a succeeding (essentially identical) pulse sequence. Required except when Scanning Sequence is EP and Sequnece Variant is not segmented k-space | acquisition |
EchoTime | stream |  | DS | 1 | Time in msec between the middle of the excitation pulse and the peak of the echo produced. In the case of segmented k-space, the TE(eff) is the time between the middle of the excitation pulse to the peak of the echo that is used to cover the center of k-space) | acquisition |
InversionTime | stream |  | DS | 1 | Time in msec after the middle of inverting RF pulse to middle of excitation pulse to detect the amount of longitudinal magnetization. Required if Scanning Sequence has value of IR | acquisition |
NumberOfAverages | stream |  | DS | 1 | Number of averages | acquisition |
ImagingFrequency | stream |  | DS | 1 | Precession frquency in MHz of the nucleus being addressed | acquisition |
ImagedNucleus | stream |  | SH | 1 | Nucleus that is resonant at the imaging frequency | acquisition |
EchoNumbers | stream |  | IS | 1 | The echo number used in generating this image. In the case of segmented k-space, it is the effective Echo Number | acquisition |
MagneticFieldStrength | stream |  | DS | 1 | Nominal Field strength of MR magnet, in Tesla | acquisition | Tesla
NumberOfPhaseEncodingSteps | stream |  | IS | 1 | Total number of lines in k-space in the y-direction collecting during acquisition | acquisition |
EchoTrainLength | stream |  | IS | 1 | Number of lines in k-space acquired per excitation per image | acquisition |
PercentSampling | stream |  | DS | 1 | Fraction of acquisition matrix lines acquired, expressed as a percent | acquisition |
PercentPhaseFieldOfView | stream |  | DS | 1 | Ration of field of view dimension in phase direction to field of view dimension in frequency direction, expressed as a percent | acquisition |
TriggerTime | stream |  | DS | 1 | Time, in msec, between peak of the R wave and the peak of the echo produced. In the case of segmented k-space, the TE(eff) is the time between the peak of the echo that is used to cover the center of k-space. Required for Scan Options which include heart gating | acquisition |
ReceivingCoil | stream |  | SH | 1 | Received coil used | acquisition |
TransmittingColi | stream |  | SH | 1 | Transmitted coil used | acquisition |
AcquisitionMatrixText | stream |  | US | 4 | Dimension of acquired frequency/phase data before reconstruction. Multi-valued: frequency rows\frequency columns\phase rows\phase columns | acquisition |
PhaseEncodingDirection | stream |  | CS | 1 | The axis of phase encoding with respect to the image. Enumerated Values: ROW = phase encoded in rows COL = phase encoded in columns | acquisition |
FlipAngle | stream |  | DS | 1 | Steady state angle in degrees to which the magnetic vector is flipped from the magnetic vector to the primary field | acquisition | Degree
VariableFlipAngleFlag | stream |  | CS | 1 | Flip angle variation applied during image acquisition. Enumerated Values: Y = yes N = no | acquisition |
SAR | stream |  | DS | 1 | Calculated whole body specific absortion rate in watts/kilogram | acquisition | Watt/kilogram
dBdt | stream |  | DS | 3 | The rate of change of the gradient coil magnetic flux density with time (T/s) | acquisition | Tesla/sec
Rows | stream |  | US | 1 | Number of rows in the image | acquisition | mm
Columns | stream |  | US | 1 | Number of columns in the image | acquisition | mm
SliceThickness | stream |  | DS | 1 | Nominal slice thickness, in mm | acquisition | mm
ImagePositionPatient | stream |  | DS | 3 | The direction cosines of the first row and the first column with respect to the patient | acquisition |
ImageOrientationPatient | stream |  | DS | 6 | The x,y and z coordinates of the upper left and hand corner (first pixel transmitted) of the image, in mm. | acquisition | mm
SliceLocation | stream |  | DS | 1 | Relative position of exposure expressed in mm | acquisition | mm
EchoLinePosition | stream |  | IS | 1 | Fourier line position with the maximal echo for the performed acquisition | acquisition |
EchoColumnPosition | stream |  | IS | 1 | Echo column position for the performed acquisition | acquisition |
EchoPartitionPosition | stream |  | IS | 1 | Echo partition position for the performed acquisition | acquisition |
Actual3DImaPartNumber | stream |  | IS | 1 | Number of a 3D partitions beginning with 0 | acquisition |
RealDwellTime | stream |  | IS | 1 | The time in ns between the beginning of sampling one data point and the beginning of sampling of next data point in the acquired signal. This means the dwell time is the sampling rate during digital conversion of an acquired signal | acquisition |
ProtocolSliceNumber | stream |  | UN | 1 | Number of the slice beginning with 0 | acquisition |
PixelFile | stream |  | UN | 1 | Used raw data file for the performed acquisition | acquisition |
PixelFileName | stream |  | LO | 1 | Used raw data file name for the performed acquisition | acquisition |
ICE_Dims | stream |  | DS | 1 | The 9 used ICE object dimensions of the performed acquisition. Combined/unset dimensions will be marked with "X". E.g.: X_2_1_1_1_1_2_1_1 | acquisition |
PixelSpacing | stream |  | DS | 2 | Physical distance in the patient between the center of each pixel, specified by a numeric pair-adjacent row spacing (delimiter) adjacent column spacing in mm | acquisition | mm
SourceImageSequence | stream |  | UI | n | A sequence which identifies the set of Image SOP Class/Instance pairs of the images which were use to derive this image | acquisition |
PixelBandwidth | stream |  | DS | 1 | Reciprocal of the total sampling period, in hertz per pixel | acquisition |
SliceMeasurementDuration | stream |  | DS | 1 | Time duration between two slices of the performed acquisition | acquisition |
SequenceMask | stream |  | UL | 1 | Parameters used for acquisition, e.g. door open, interpolation, raw filter, Siemens seqence .· | acquisition |
AcquisitionMatrixText | stream |  | SH | 1 | Used acquisition matrix description | acquisition |
MeasuredFourierLines | stream |  | IS | 1 | Number of performed fourier lines | acquisition |
MR Protocol |  |  |  |  |  |  |
ulVersion | stream | 3 | UL | 1 | Protocol version | acquisition |
tSequenceFileName | stream | 3 | ST | 1 | Sequence file name for actual measurement protocol | acquisition |
tProtocolName | stream | 3 | ST | 1 | Name of actual measurement protocol | acquisition |
tReferenceImage0 | stream | 3 | LO | 1 | Referenced image | acquisition |
tReferenceImage1 | stream | 3 | LO | 1 | Referenced image | acquisition |
tReferenceImage2 | stream | 3 | LO | 1 | Referenced image | acquisition |
lScanRegionPosSag | stream | 3 | FD | 1 | Desired table position in series block coordinate system | acquisition |
lScanRegionPosCor | stream | 3 | FD | 1 | Desired table position in series block coordinate system | acquisition |
lScanRegionPosTra | stream | 3 | FD | 1 | Desired table position in series block coordinate system | acquisition |
ucScanRegionPosValid | stream | 3 | SH | 1 | Valid flag for desired table position in series block coordinate system | acquisition |
aucSpare | stream | 3 | SH | 1 | Reserved | acquisition |
lScanRegionDelta | stream | 3 | SL | 1 | Scan Region Position/Move [mm] | acquisition | mm
sProtConsistencyInfo.tBaselineString | stream | 3 | LO | 1 | Baseline consistence info | acquisition |
sProtConsistencyInfo.tGradCoilName | stream | 3 | SH | 1 | Coil name consistence info | acquisition |
sProtConsistencyInfo.tGradAmplifierName | stream | 3 | LO | 1 | Gradient amplifier consistence info | acquisition |
sProtConsistencyInfo.flNominalB0 | stream | 3 | FD | 1 | Nominal Bo compensation consistence | acquisition |
sGRADSPEC.sEddyCompensationX.aflAmplitude | stream | 3 | FD | 5 | Eddy compensation x amplitude gradient system specification | acquisition |
sGRADSPEC.sEddyCompensationX.aflTimeConstant | stream | 3 | FD | 5 | Eddy compensation x time parameter gradient system specification | acquisition |
sGRADSPEC.sEddyCompensationY.aflAmplitude | stream | 3 | FD | 5 | Eddy compensation y amplitude gradient system specification | acquisition |
sGRADSPEC.sEddyCompensationY.aflTimeConstant | stream | 3 | FD | 5 | Eddy compensation y time parameter gradient system specification | acquisition |
sGRADSPEC.sEddyCompensationZ.aflAmplitude | stream | 3 | FD | 5 | Eddy compensation z amplitude gradient system specification | acquisition |
sGRADSPEC.sEddyCompensationZ.aflTimeConstant | stream | 3 | FD | 5 | Eddy compensation z time parameter gradient system specification | acquisition |
sGRADSPEC.bB0CompensationValid | stream | 3 | SL | 1 | B0 compensation gradient system specification valid flag | acquisition |
sGRADSPEC.sCrossTermCompensationXY.aflAmplitude | stream | 3 | FD | 5 | Crossterm compensation xy amplitude gradient system specification | acquisition |
sGRADSPEC.sCrossTermCompensationXY.aflTimeConstant | stream | 3 | FD | 5 | Crossterm compensation xy time parameter gradient system specification | acquisition |
sGRADSPEC.sCrossTermCompensationXZ.aflAmplitude | stream | 3 | FD | 5 | Crossterm compensation xz amplitude gradient system specification | acquisition |
sGRADSPEC.sCrossTermCompensationXZ.aflTimeConstant | stream | 3 | FD | 5 | Crossterm compensation xz time parameter gradient system specification | acquisition |
sGRADSPEC.sCrossTermCompensationYX.aflAmplitude | stream | 3 | FD | 5 | Crossterm compensation xz amplitude gradient system specification | acquisition |
sGRADSPEC.sCrossTermCompensationYX.aflTimeConstant | stream | 3 | FD | 5 | Crossterm compensation yx time parameter gradient system specification | acquisition |
sGRADSPEC.sCrossTermCompensationYZ.aflAmplitude | stream | 3 | FD | 5 | Crossterm compensation yz amplitude gradient system specification | acquisition |
sGRADSPEC.sCrossTermCompensationYZ.aflTimeConstant | stream | 3 | FD | 5 | Crossterm compensation yz time parameter gradient system specification | acquisition |
sGRADSPEC.sCrossTermCompensationZX.aflAmplitude | stream | 3 | FD | 5 | Crossterm compensation zx amplitude gradient system specification | acquisition |
sGRADSPEC.sCrossTermCompensationZX.aflTimeConstant | stream | 3 | FD | 5 | Crossterm compensation zx time parameter gradient system specification | acquisition |
sGRADSPEC.sCrossTermCompensationZY.aflAmplitude | stream | 3 | FD | 5 | Crossterm compensation zx amplitude gradient system specification | acquisition |
sGRADSPEC.sCrossTermCompensationZY.aflTimeConstant | stream | 3 | FD | 5 | Crossterm compensation zy time parameter gradient system specification | acquisition |
sGRADSPEC.bCrossTermCompensationValid | stream | 3 | SL | 1 | Crossterm compensation gradient system specification valid flag | acquisition |
sGRADSPEC.lOffsetX | stream | 3 | SL | 1 | Gradient offset x direction [bit pattern] | acquisition |
sGRADSPEC.lOffsetY | stream | 3 | SL | 1 | Gradient offset y direction [bit pattern] | acquisition |
sGRADSPEC.lOffsetZ | stream | 3 | SL | 1 | Gradient offset z direction [bit pattern] | acquisition |
sGRADSPEC.bOffsetValid | stream | 3 | SL | 1 | Gradient offsets valid flag | acquisition |
sGRADSPEC.lDelayX | stream | 3 | SL | 1 | Gradient delay x direction | acquisition |
sGRADSPEC.lDelayY | stream | 3 | SL | 1 | Gradient delay y direction | acquisition |
sGRADSPEC.lDelayY | stream | 3 | SL | 1 | Gradient delay z direction | acquisition |
sGRADSPEC.bDelayValid | stream | 3 | SL | 1 | Gradient delay valid flag | acquisition |
sGRADSPEC.flSensitivityX | stream | 3 | FD | 1 | Gradient sensitivity x direction [mT/m] | acquisition | mT/m
sGRADSPEC.flSensitivityY | stream | 3 | FD | 1 | Gradient sensitivity y direction [mT/m] | acquisition | mT/m
sGRADSPEC.flSensitivityZ | stream | 3 | FD | 1 | Gradient sensitivity z direction [mT/m] | acquisition | mT/m
sGRADSPEC.bSensitivityValid | stream | 3 | SL | 1 | Gradient sensitivity valid flag | acquisition |
sGRADSPEC.flGSWDMinRiseTime | stream | 3 | FD | 1 | Minimum gradient rise time for mode GRAD_GSWD_RISETIME | acquisition | mA
sGRADSPEC.alShimCurrent | stream | 3 | SL | 15 | Shim current parameter [mA] | acquisition |
sGRADSPEC.bShimCurrentValid | stream | 3 | SL | 1 | Shim current parameter valid flag | acquisition |
sGRADSPEC.ucMode | stream | 3 | SH | 1 | Gradient mode: fast, normal, whisper | acquisition |
sGRADSPEC.ucSpare0 | stream | 3 | SH | 1 | Reserved | acquisition |
sGRADSPEC.ucSpare1 | stream | 3 | SH | 1 | Reserved | acquisition |
sGRADSPEC.ucSpare2 | stream | 3 | SH | 1 | Reserved | acquisition |
sTXSPEC.asNucleusInfo[0].tNucleus | stream | 3 | SH | 1 | Transmitter system nucleus | acquisition |
sTXSPEC.asNucleusInfo[0].lFrequency | stream | 3 | SL | 1 | Transmitter system frequency [Hz] | acquisition | Hz
sTXSPEC.asNucleusInfo[0].bFrequencyValid | stream | 3 | SL | 1 | Frequency valid flag | acquisition |
sTXSPEC.asNucleusInfo[0].lDeltaFrequency | stream | 3 | SL | 1 | Offset from center frequency (lFrequency) | acquisition |
sTXSPEC.asNucleusInfo[0].flReferenceAmplitude | stream | 3 | FD | 1 | Transmitter reference amplitude [V] | acquisition | V
sTXSPEC.asNucleusInfo[0].bReferenceAmplitudeValid | stream | 3 | SL | 1 | Reference amplitude valid flag | acquisition |
sTXSPEC.asNucleusInfo[0].flAmplitudeCorrection | stream | 3 | FD | 1 | Transmitter amplitude correction factor, e.g. used for water suppression | acquisition |
sTXSPEC.asNucleusInfo[0].bAmplitudeCorrectionValid | stream | 3 | SL | 1 | Amplitude correction valid flag | acquisition |

Last Updated on 07.02.2002